Package: loon.ggplot
Type: Package
Title: A Grammar of Interactive Graphics
Version: 1.3.5
Authors@R: c(
  person('Zehao', 'Xu', email = 'z267xu@gmail.com', role = c("aut", "cre")),
  person('R. Wayne', 'Oldford', email = 'rwoldford@uwaterloo.ca', role = c("aut"))
  )
Description: Provides a bridge between the 'loon' and  'ggplot2' packages.  Extends the grammar of ggplot to add clauses to create interactive 'loon' plots. Existing ggplot(s) can be turned into interactive 'loon' plots and 'loon' plots into static ggplot(s); the function 'loon.ggplot()' is the bridge from one plot structure to the other.
License: GPL-2
BugReports: https://github.com/great-northern-diver/loon.ggplot/issues
Depends: R (>= 3.4.0), tcltk, methods, loon (>= 1.3.2), ggplot2,
        ggmulti
Imports: stats, utils, grDevices, grid, gridExtra, scales, patchwork,
        rlang
Suggests: GGally, magrittr, tidyr, zenplots, dplyr, gtable, png, tools,
        tibble, testthat, knitr, rmarkdown, maps, hexbin, nycflights13,
        ggplot2movies
RoxygenNote: 7.3.1
Encoding: UTF-8
VignetteBuilder: knitr
Language: en-US
NeedsCompilation: no
Packaged: 2025-10-10 09:18:26 UTC; zehaoxu
Author: Zehao Xu [aut, cre],
  R. Wayne Oldford [aut]
Maintainer: Zehao Xu <z267xu@gmail.com>
Repository: CRAN
Date/Publication: 2025-10-10 10:20:02 UTC
Built: R 4.6.0; ; 2026-04-30 10:23:13 UTC; unix
