# Generated by roxygen2: do not edit by hand

S3method("[",l_facet_ggplot)
S3method("[",l_ggplot)
S3method("[<-",l_facet_ggplot)
S3method("[<-",l_ggplot)
S3method(Cartesianxy2Polarxy,GeomAbline)
S3method(Cartesianxy2Polarxy,GeomHline)
S3method(Cartesianxy2Polarxy,GeomPath)
S3method(Cartesianxy2Polarxy,GeomRect)
S3method(Cartesianxy2Polarxy,GeomSegment)
S3method(Cartesianxy2Polarxy,GeomVline)
S3method(Cartesianxy2Polarxy,default)
S3method(g_getPlots,default)
S3method(g_getPlots,l_pairs)
S3method(ggplot2loon,default)
S3method(ggplot2loon,ggmatrix)
S3method(ggplot2loon,ggplot)
S3method(ggplot2loon,patchwork)
S3method(ggplot_add,Interactivity)
S3method(l_cget,l_facet_ggplot)
S3method(l_configure,l_facet_ggplot)
S3method(l_getLocations,l_facet_ggplot)
S3method(l_getLocations,l_ggmatrix)
S3method(l_getPlots,l_facet_ggplot)
S3method(l_getPlots,l_ggmatrix)
S3method(l_getSubtitles,l_facet_ggplot)
S3method(l_getSubtitles,l_facet_grid)
S3method(l_getSubtitles,l_facet_wrap)
S3method(l_get_arrangeGrobArgs,l_facet_ggplot)
S3method(layout_coords,l_facet_ggplot)
S3method(layout_coords,l_hist)
S3method(layout_coords,l_plot)
S3method(loon.ggplot,gg)
S3method(loon.ggplot,l_ggplot)
S3method(loon.ggplot,loon)
S3method(loon.ggplot,zenplot)
S3method(loon2ggplot,default)
S3method(loon2ggplot,l_compound)
S3method(loon2ggplot,l_facet_ggplot)
S3method(loon2ggplot,l_facet_grid)
S3method(loon2ggplot,l_facet_wrap)
S3method(loon2ggplot,l_graph)
S3method(loon2ggplot,l_hist)
S3method(loon2ggplot,l_layer_graph)
S3method(loon2ggplot,l_layer_group)
S3method(loon2ggplot,l_layer_histogram)
S3method(loon2ggplot,l_layer_line)
S3method(loon2ggplot,l_layer_lines)
S3method(loon2ggplot,l_layer_oval)
S3method(loon2ggplot,l_layer_points)
S3method(loon2ggplot,l_layer_polygon)
S3method(loon2ggplot,l_layer_polygons)
S3method(loon2ggplot,l_layer_rectangle)
S3method(loon2ggplot,l_layer_rectangles)
S3method(loon2ggplot,l_layer_scatterplot)
S3method(loon2ggplot,l_layer_text)
S3method(loon2ggplot,l_layer_texts)
S3method(loon2ggplot,l_pairs)
S3method(loon2ggplot,l_patchwork)
S3method(loon2ggplot,l_plot)
S3method(loon2ggplot,l_plot3D)
S3method(loon2ggplot,l_serialaxes)
S3method(loon2ggplot,zenLoon)
S3method(loonGrob_layoutType,l_facet_ggplot)
S3method(loonLayer,GeomAbline)
S3method(loonLayer,GeomBoxplot)
S3method(loonLayer,GeomContour)
S3method(loonLayer,GeomCrossbar)
S3method(loonLayer,GeomCurve)
S3method(loonLayer,GeomDensity)
S3method(loonLayer,GeomDotplot)
S3method(loonLayer,GeomErrorbar)
S3method(loonLayer,GeomErrorbarh)
S3method(loonLayer,GeomHex)
S3method(loonLayer,GeomHline)
S3method(loonLayer,GeomImageGlyph)
S3method(loonLayer,GeomLabel)
S3method(loonLayer,GeomLinerange)
S3method(loonLayer,GeomPath)
S3method(loonLayer,GeomPoint)
S3method(loonLayer,GeomPointrange)
S3method(loonLayer,GeomPolygon)
S3method(loonLayer,GeomPolygonGlyph)
S3method(loonLayer,GeomQuantile)
S3method(loonLayer,GeomRaster)
S3method(loonLayer,GeomRect)
S3method(loonLayer,GeomRibbon)
S3method(loonLayer,GeomRug)
S3method(loonLayer,GeomSegment)
S3method(loonLayer,GeomSerialAxesGlyph)
S3method(loonLayer,GeomSmooth)
S3method(loonLayer,GeomStep)
S3method(loonLayer,GeomText)
S3method(loonLayer,GeomViolin)
S3method(loonLayer,GeomVline)
S3method(loonLayer,default)
S3method(names,l_facet_ggplot)
S3method(print,l_ggplot)
export(Cartesianxy2Polarxy)
export(active)
export(g_getPlots)
export(geom_imageGlyph)
export(geom_pointrangeGlyph)
export(geom_polygonGlyph)
export(geom_serialAxesGlyph)
export(geom_textGlyph)
export(get_activeGeomLayers)
export(get_scaledData)
export(ggSerialAxes)
export(gg_pipe)
export(ggplot2loon)
export(hover)
export(interactivity)
export(is.CoordPolar)
export(itemLabel)
export(l_getSubtitles)
export(l_ggplot)
export(layout_coords)
export(lggplot)
export(linking)
export(loon.ggplot)
export(loon2ggplot)
export(loonLayer)
export(scaleBox)
export(scale_multi)
export(selecting)
export(selection)
export(zoom)
import(ggplot2)
import(grid)
import(loon)
import(methods)
import(patchwork)
import(rlang)
import(scales)
import(stats)
import(tcltk)
import(utils)
importFrom(ggmulti,andrews)
importFrom(ggmulti,coord_serialaxes)
importFrom(ggmulti,geom_image_glyph)
importFrom(ggmulti,geom_polygon_glyph)
importFrom(ggmulti,geom_serialaxes_glyph)
importFrom(grDevices,as.raster)
importFrom(grDevices,col2rgb)
importFrom(grDevices,extendrange)
importFrom(grDevices,rgb)
importFrom(gridExtra,arrangeGrob)
importFrom(gridExtra,tableGrob)
